<?php

namespace Drupal\Tests\smart_db_tools\Kernel\Command;

use Drupal\smart_db_tools\Command\SmartDbDumpCommand;
use Drupal\Tests\system\Kernel\Scripts\DbDumpCommandTest;
use Symfony\Component\Console\Tester\CommandTester;

/**
 * Tests that SmartDbDumpCommand works correctly.
 *
 * @group smart_db_tools
 * @group console
 *
 * @see \Drupal\Tests\system\Kernel\Scripts\DbDumpCommandTest
 */
class SmartDbDumpCommandTest extends DbDumpCommandTest {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'smart_db_tools',
  ];

  /**
   * {@inheritdoc}
   */
  public function testDbDumpCommand() {
    $command = new SmartDbDumpCommand();
    $command_tester = new CommandTester($command);
    $command_tester->execute([]);

    // Assert that insert exists and that some expected fields exist.
    $output = $command_tester->getDisplay();
    $this->assertStringContainsString("createTable('router", $output, 'Table router found');
    $this->assertStringContainsString("insert('router", $output, 'Insert found');
    $this->assertStringContainsString("'name' => 'test", $output, 'Insert name field found');
    $this->assertStringContainsString("'path' => 'test", $output, 'Insert path field found');
    $this->assertStringContainsString("'pattern_outline' => 'test", $output, 'Insert pattern_outline field found');
    $version = \Drupal::VERSION;
    $version_normalized = preg_replace(
      [
        '/\.x-dev$/',
        '/\.(\d+)-dev$/',
      ],
      [
        '.0',
        '.$1',
      ],
      $version
    );
    if (version_compare($version_normalized, '9.2', 'ge')) {
      $this->assertStringContainsString("// phpcs:ignoreFile", $output);
    }
    else {
      $this->assertStringContainsString("// @codingStandardsIgnoreFile", $output);
    }

    $this->assertStringContainsString("This file was generated by the Drupal {$version} db-tools.php script.", $output);
  }

  /**
   * {@inheritdoc}
   */
  public function testSchemaOnly() {
    $command = new SmartDbDumpCommand();
    $command_tester = new CommandTester($command);
    $command_tester->execute(['--schema-only' => 'router']);

    // Assert that insert statement doesn't exist for schema only table.
    $output = $command_tester->getDisplay();
    $this->assertStringContainsString("createTable('router", $output, 'Table router found');
    $this->assertStringNotContainsString("insert('router", $output, 'Insert not found');
    $this->assertStringNotContainsString("'name' => 'test", $output, 'Insert name field not found');
    $this->assertStringNotContainsString("'path' => 'test", $output, 'Insert path field not found');
    $this->assertStringNotContainsString("'pattern_outline' => 'test", $output, 'Insert pattern_outline field not found');

    // Assert that insert statement doesn't exist for wildcard schema only
    // match.
    $command_tester->execute(['--schema-only' => 'route.*']);
    $output = $command_tester->getDisplay();
    $this->assertStringContainsString("createTable('router", $output, 'Table router found');
    $this->assertStringNotContainsString("insert('router", $output, 'Insert not found');
    $this->assertStringNotContainsString("'name' => 'test", $output, 'Insert name field not found');
    $this->assertStringNotContainsString("'path' => 'test", $output, 'Insert path field not found');
    $this->assertStringNotContainsString("'pattern_outline' => 'test", $output, 'Insert pattern_outline field not found');
  }

}
